export function cptSex(val) {
    if (val === 1 || val === '1') {
        return '男'
    } else if (val === 2 || val === '2') {
        return '女'
    } else {
        return ''
    }
}

export function cptOperation(val) {
    switch (val) {
        case '1':
            return '传统手术'
        case '2':
            return '介入手术'
        case '3':
            return '微创手术'
        case '4':
            return '恶性肿瘤放射治疗'
        case '5':
            return '恶性肿瘤化学治疗'
        case '6':
            return '恶性肿瘤放疗加化疗'
        case '7':
            return '恶性肿瘤姑息治疗'
        default:
            return '非手术'
    }
}

export function cptDisDiagStatus(val) {
    switch (val) {
        case 0:
            return '好转/治愈'
        case 1:
            return '未愈'
        case 2:
            return '转院（医院要求）'
        case 3:
            return '转院（病人要求）'
        case 4:
            return '转科'
        case 5:
            return '无效'
        case 6:
            return '死亡'
        case 7:
            return '双向转诊'
        case 9:
            return '其他'
        default:
            return '未填'
    }
}

export function getResponceTypeName(val) {
    switch (val) {
        case '01':
            return 'zifei'
        case '02':
        case '10':
            return 'shengyb'
        case '04':
            return 'xnh'
        case '03':
        case '09':
            return 'shiyb'
    }
}

export function cptInsutype(val) {
    switch (val) {
        case '310':
            return '职工基本医疗保险'
        case '320':
            return '公务员医疗补助'
        case '330':
            return '大额医疗费用补助'
        case '340':
            return '离休人员医疗保障'
        case '390':
            return '城乡居民基本医疗保险'
        case '392':
            return '城乡居民大病医疗保险'
        case '510':
            return '生育保险'
        default:
            return ''
    }
}

export function cptPersType(val) {
    switch (val) {
        case '11':
            return '在职'
        case '21':
            return '退休'
        case '31':
            return '离休'
        case '32':
            return '老红军'
        case '33':
            return '一至六级残废军人'
        case '34':
            return '医疗照顾人员'
        case '41':
            return '学龄前儿童'
        case '42':
            return '中小学生'
        case '43':
            return '大学生'
        case '50':
            return '成年居民（非从业）'
        case '60':
            return '老年居民'
        case '91':
            return '其他人员'
    }
}

export function cptYbState(val) {
    switch (val) {
        case '0':
            return '无效'
        case '1':
            return '正常参保'
        case '2':
            return '暂停参保'
        case '3':
            return '终止参保'
    }
}

export function cptZyState(val) {
    return val === '1' ? '在院' : '不在院'
}

//获取医嘱审核状态
export function yZauditStatus(val) {
    switch (val) {
        case 1:
            return '<span style="color: orange;">待审核</span>'
        case 2:
            return '<span style="color: green;">已通过</span>'
        case 3:
            return '<span style="color: red;">已驳回</span>'
        case 4:
            return '<span style="color: blue;">数据撤回</span>'
        default:
            return '<span style="color:grey">未知</span>'
    }
}

//住院费用商品描述
export function describe(val) {
    switch (val) {
        case '01':
            return '药品(小)'
        case '99':
            return '药品（大）'
        default:
            return '项目'
    }
}

//费用的状态
export function costState(val) {
    switch (val) {
        case '1':
            return '录入'
        case '2':
            return '上账'
        default:
            return '结算'
    }
}

export const conversionRefundFlag = (val) => {
    switch (val) {
        case -1:
            return "<span>退费数据</span>"
        case -2:
            return "<span>申请退药</span>"
        case  -3:
            return "<span>拒绝退药</span>"
    }
}

export function babyOrNot(val) {
    switch (val) {
        case '0':
            return '否'
        case '2':
            return '是'
        default:
            return '未知'
    }
}

export function aerYouSure(val) {
    switch (val) {
        case '0':
            return '否'
        case '2':
            return '是'
        default:
            return '未知'
    }
}

//查看新冠疫苗是否可以预约
export function enableFlagToString(val) {
    switch (val) {
        case '1':
            return '<span style="color: green;">是</span>'
        case '0':
            return '<span style="color: red;">否</span>'
        case 1:
            return '<span style="color: green;">是</span>'
        case 0:
            return '<span style="color: red;">否</span>'
    }
}

export function cptPsnCertType(val) {
    switch (val) {
        case '01':
            return '居民身份证'
        case '02':
            return '居民户口簿'
        case '03':
            return '护照'
        case '04':
            return '军官证'
        case '05':
            return '驾驶证'
        case '06':
            return '港澳居民来往内地通行证'
        case '07':
            return '台湾居民来往内地通行证'
        case '99':
            return '其他身份证件'
    }
}

export function cptMedType(val) {
    switch (val) {
        case '11':
            return '普通门诊'
        case '12':
            return '门诊挂号'
        case '13':
            return '急诊'
        case '14':
            return '门诊慢特病'
        case '2101':
            return '普通住院'
        case '22':
            return '外伤住院'
        case '23':
            return '转外诊治住院'
        case '24':
            return '急诊转住院'
        case '41':
            return '定点药店购药'
        case '51':
            return '生育门诊'
        case '52':
            return '生育住院'
        case '53':
            return '计划生育手术费'
        case '91':
            return '其他门诊'
        case '92':
            return '其他住院'
        case '93':
            return '其他购药'
        case '99':
            return '地方扩展医疗类别'
    }
}

export function cptYesOrNo(val) {
    if (val === 1 || val === '1') {
        return '是'
    }
    return '否'
}
